summaryrefslogtreecommitdiffstats
path: root/chrome/browser/external_tab_container.h
diff options
context:
space:
mode:
authorjcampan@chromium.org <jcampan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-06-08 21:27:28 +0000
committerjcampan@chromium.org <jcampan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-06-08 21:27:28 +0000
commit90daadb496f6e589f533fbd2fe3727cf86204f82 (patch)
tree59304e0a7ae87410a70eb9d4a7ab1412c38220c5 /chrome/browser/external_tab_container.h
parentc55afea2eec383549358d934e19b29d78fd4e41b (diff)
downloadchromium_src-90daadb496f6e589f533fbd2fe3727cf86204f82.zip
chromium_src-90daadb496f6e589f533fbd2fe3727cf86204f82.tar.gz
chromium_src-90daadb496f6e589f533fbd2fe3727cf86204f82.tar.bz2
Rename the TabContents::SetInitialFocus(reverse) method to TabContents::FocusThroughTabTraversal(reverse), as SetInitialiFocus can be easily confused with TabContentView::SetInitialFocus().
BUG=None TEST=None Review URL: http://codereview.chromium.org/118392 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@17900 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/external_tab_container.h')
-rw-r--r--chrome/browser/external_tab_container.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/external_tab_container.h b/chrome/browser/external_tab_container.h
index 4edb8b9..3d65321 100644
--- a/chrome/browser/external_tab_container.h
+++ b/chrome/browser/external_tab_container.h
@@ -44,8 +44,8 @@ class ExternalTabContainer : public TabContentsDelegate,
// message it did not process
void ProcessUnhandledAccelerator(const MSG& msg);
- // See TabContents::SetInitialFocus. Called from AutomationProvider.
- void SetInitialFocus(bool reverse);
+ // See TabContents::FocusThroughTabTraversal. Called from AutomationProvider.
+ void FocusThroughTabTraversal(bool reverse);
// A helper method that tests whether the given window is an
// ExternalTabContainer window